.. image:: https://travis-ci.org/cdusold/DriveLink.png
   :target: https://travis-ci.org/cdusold/DriveLink
   :alt: Build Status
.. image:: https://coveralls.io/repos/github/cdusold/DriveLink/badge.svg?branch=master
   :target: https://coveralls.io/github/cdusold/DriveLink?branch=master
   :alt: Coverage Status
.. image:: https://readthedocs.org/projects/drivelink/badge/?version=latest
   :target: http://drivelink.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

About
=====

A collection of memory conserving data structures designed to give peak performance
for on demand data usage while maintaining a constant use of RAM.

Available from `PyPI <https://pypi.python.org/pypi/DriveLink>`_, and easily installed through `pip install DriveLink`. Documentation available at `Read The Docs <http://drivelink.rtfd.org/>`_ and source available on `Github <https://github.com/cdusold/DriveLink>`_.
